//
//  ItsmoNaviOauthClient.h
//
// Your use of this product is subject to the Acceptable Use Policy (see: http://support.e-map.ne.jp/manuals/V20/index.html?API%CD%F8%CD%D1%B5%AC%CC%F3)
// This product includes software under the MIT License (see: https://code.google.com/p/oauthconsumer/)
//

#import <UIKit/UIKit.h>

@interface ItsmoNaviOauthClient : NSObject <UIWebViewDelegate>

/**
 * 環境を表します。
 */
typedef enum {
    /**
     *  本番環境です。
     */
    ENV_PRODUCTION,
    /**
     *  検証環境です。
     */
    ENV_TEST
} ENV;

/**
 *  APIファイルを正常にロードした後、コールバック処理を行うブロックオブジェクト
 */
typedef void (^CallbackSuccess)(void);

/**
 *  例外発生後、コールバック処理を行うブロックオブジェクト
 *
 *  @param error エラーオブジェクト
 */
typedef void (^CallbackError)(NSError *error);


/**
 *  インスタンスを生成します。
 *
 *  @param key    コンシューマ・キー
 *  @param secret コンシューマ・シークレット
 *  @param env    環境情報。本番環境または検証環境を指定する
 *
 */
- (id)initWithOauthInfo:(NSString *)key secret:(NSString *)secret env:(ENV) env;
/**
 *  画面情報を設定します。
 *
 *  @param webView 表示画面
 *  @param file    表示対象であるhtmlファイル名
 *  @param dir     表示対象であるhtmlファイルが存在するディレクトリ
 *  @param param   ローダーのパラメータ
 */
- (void)prepareWebViewInfo:(UIWebView *)webView file:(NSString *)file dir:(NSString *)dir param:(NSString *)param;
/**
 *  APIファイルをロードします。
 *
 *  @param success APIファイルを正常にロードした後、コールバック処理を行うブロックオブジェクト
 *  @param failure 例外発生後、コールバック処理を行うブロックオブジェクト
 */
- (void)loadJs:(CallbackSuccess)success failure:(CallbackError)failure;

@end

